summaryrefslogtreecommitdiffstats
path: root/chrome
diff options
context:
space:
mode:
Diffstat (limited to 'chrome')
-rw-r--r--chrome/browser/browser_url_handler.cc4
-rw-r--r--chrome/browser/dom_ui/web_ui_factory.cc12
-rw-r--r--chrome/browser/extensions/extension_bookmark_manager_api.cc16
-rw-r--r--chrome/browser/extensions/extension_function_dispatcher.cc8
-rw-r--r--chrome/browser/extensions/extension_override_apitest.cc10
-rw-r--r--chrome/browser/extensions/extension_popup_api.cc2
-rw-r--r--chrome/browser/extensions/extension_service.cc10
-rw-r--r--chrome/browser/extensions/extension_web_ui.cc (renamed from chrome/browser/extensions/extension_dom_ui.cc)54
-rw-r--r--chrome/browser/extensions/extension_web_ui.h (renamed from chrome/browser/extensions/extension_dom_ui.h)12
-rw-r--r--chrome/browser/prefs/browser_prefs.cc4
-rw-r--r--chrome/browser/tab_contents/web_drag_dest_gtk.cc4
-rw-r--r--chrome/browser/tab_contents/web_drop_target_win.cc4
-rw-r--r--chrome/chrome_browser.gypi4
13 files changed, 72 insertions, 72 deletions
diff --git a/chrome/browser/browser_url_handler.cc b/chrome/browser/browser_url_handler.cc
index 211d168..1345cf1 100644
--- a/chrome/browser/browser_url_handler.cc
+++ b/chrome/browser/browser_url_handler.cc
@@ -7,7 +7,7 @@
#include "base/string_util.h"
#include "chrome/browser/browser_about_handler.h"
#include "chrome/browser/dom_ui/web_ui_factory.h"
-#include "chrome/browser/extensions/extension_dom_ui.h"
+#include "chrome/browser/extensions/extension_web_ui.h"
#include "chrome/browser/profiles/profile.h"
#include "chrome/common/url_constants.h"
#include "googleurl/src/gurl.h"
@@ -94,7 +94,7 @@ void BrowserURLHandler::InitURLHandlers() {
// Add the default URL handlers.
url_handlers_.push_back(
- HandlerPair(&ExtensionDOMUI::HandleChromeURLOverride, null_handler));
+ HandlerPair(&ExtensionWebUI::HandleChromeURLOverride, null_handler));
// about:
url_handlers_.push_back(HandlerPair(&WillHandleBrowserAboutURL,
null_handler));
diff --git a/chrome/browser/extensions/extension_bookmark_manager_api.cc b/chrome/browser/extensions/extension_bookmark_manager_api.cc
index 2edf970..7f77ac5 100644
--- a/chrome/browser/extensions/extension_bookmark_manager_api.cc
+++ b/chrome/browser/extensions/extension_bookmark_manager_api.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -15,8 +15,8 @@
#include "chrome/browser/dom_ui/chrome_url_data_manager.h"
#include "chrome/browser/extensions/extension_bookmark_helpers.h"
#include "chrome/browser/extensions/extension_bookmarks_module_constants.h"
-#include "chrome/browser/extensions/extension_dom_ui.h"
#include "chrome/browser/extensions/extension_event_router.h"
+#include "chrome/browser/extensions/extension_web_ui.h"
#include "chrome/browser/profiles/profile.h"
#include "chrome/browser/renderer_host/render_view_host.h"
#include "chrome/browser/tab_contents/tab_contents.h"
@@ -344,10 +344,10 @@ bool StartDragBookmarkManagerFunction::RunImpl() {
if (dispatcher()->render_view_host()->delegate()->GetRenderViewType() ==
ViewType::TAB_CONTENTS) {
- ExtensionDOMUI* dom_ui =
- static_cast<ExtensionDOMUI*>(dispatcher()->delegate());
+ ExtensionWebUI* web_ui =
+ static_cast<ExtensionWebUI*>(dispatcher()->delegate());
bookmark_utils::DragBookmarks(
- profile(), nodes, dom_ui->tab_contents()->GetNativeView());
+ profile(), nodes, web_ui->tab_contents()->GetNativeView());
return true;
} else {
@@ -382,10 +382,10 @@ bool DropBookmarkManagerFunction::RunImpl() {
if (dispatcher()->render_view_host()->delegate()->GetRenderViewType() ==
ViewType::TAB_CONTENTS) {
- ExtensionDOMUI* dom_ui =
- static_cast<ExtensionDOMUI*>(dispatcher()->delegate());
+ ExtensionWebUI* web_ui =
+ static_cast<ExtensionWebUI*>(dispatcher()->delegate());
ExtensionBookmarkManagerEventRouter* router =
- dom_ui->extension_bookmark_manager_event_router();
+ web_ui->extension_bookmark_manager_event_router();
DCHECK(router);
const BookmarkNodeData* drag_data = router->GetBookmarkNodeData();
diff --git a/chrome/browser/extensions/extension_function_dispatcher.cc b/chrome/browser/extensions/extension_function_dispatcher.cc
index 0aafd92..839b341 100644
--- a/chrome/browser/extensions/extension_function_dispatcher.cc
+++ b/chrome/browser/extensions/extension_function_dispatcher.cc
@@ -24,15 +24,11 @@
#include "chrome/browser/extensions/extension_clipboard_api.h"
#include "chrome/browser/extensions/extension_context_menu_api.h"
#include "chrome/browser/extensions/extension_cookies_api.h"
-#include "chrome/browser/extensions/extension_dom_ui.h"
#include "chrome/browser/extensions/extension_function.h"
#include "chrome/browser/extensions/extension_history_api.h"
#include "chrome/browser/extensions/extension_idle_api.h"
#include "chrome/browser/extensions/extension_i18n_api.h"
#include "chrome/browser/extensions/extension_infobar_module.h"
-#if defined(TOOLKIT_VIEWS)
-#include "chrome/browser/extensions/extension_input_api.h"
-#endif
#include "chrome/browser/extensions/extension_management_api.h"
#include "chrome/browser/extensions/extension_message_service.h"
#include "chrome/browser/extensions/extension_metrics_module.h"
@@ -48,6 +44,7 @@
#include "chrome/browser/extensions/extension_tabs_module.h"
#include "chrome/browser/extensions/extension_test_api.h"
#include "chrome/browser/extensions/extension_tts_api.h"
+#include "chrome/browser/extensions/extension_web_ui.h"
#include "chrome/browser/extensions/extension_webstore_private_api.h"
#include "chrome/browser/extensions/extensions_quota_service.h"
#include "chrome/browser/extensions/extension_service.h"
@@ -62,6 +59,9 @@
#include "chrome/common/url_constants.h"
#include "third_party/skia/include/core/SkBitmap.h"
+#if defined(TOOLKIT_VIEWS)
+#include "chrome/browser/extensions/extension_input_api.h"
+#endif
// FactoryRegistry -------------------------------------------------------------
diff --git a/chrome/browser/extensions/extension_override_apitest.cc b/chrome/browser/extensions/extension_override_apitest.cc
index 634465b..877fe11 100644
--- a/chrome/browser/extensions/extension_override_apitest.cc
+++ b/chrome/browser/extensions/extension_override_apitest.cc
@@ -1,11 +1,11 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#include "chrome/browser/browser_list.h"
#include "chrome/browser/extensions/extension_apitest.h"
-#include "chrome/browser/extensions/extension_dom_ui.h"
#include "chrome/browser/extensions/extension_service.h"
+#include "chrome/browser/extensions/extension_web_ui.h"
#include "chrome/browser/prefs/pref_service.h"
#include "chrome/browser/profiles/profile.h"
#include "chrome/browser/tab_contents/tab_contents.h"
@@ -19,7 +19,7 @@ class ExtensionOverrideTest : public ExtensionApiTest {
// There should be no duplicate entries in the preferences.
const DictionaryValue* overrides =
browser()->profile()->GetPrefs()->GetDictionary(
- ExtensionDOMUI::kExtensionURLOverrides);
+ ExtensionWebUI::kExtensionURLOverrides);
ListValue* values = NULL;
if (!overrides->GetList("history", &values))
@@ -119,7 +119,7 @@ IN_PROC_BROWSER_TEST_F(ExtensionOverrideTest, ShouldNotCreateDuplicateEntries) {
// Simulate several LoadExtension() calls happening over the lifetime of
// a preferences file without corresponding UnloadExtension() calls.
for (size_t i = 0; i < 3; ++i) {
- ExtensionDOMUI::RegisterChromeURLOverrides(
+ ExtensionWebUI::RegisterChromeURLOverrides(
browser()->profile(),
browser()->profile()->GetExtensionService()->extensions()->back()->
GetChromeURLOverrides());
@@ -138,7 +138,7 @@ IN_PROC_BROWSER_TEST_F(ExtensionOverrideTest, ShouldCleanUpDuplicateEntries) {
list->Append(Value::CreateStringValue("http://www.google.com/"));
browser()->profile()->GetPrefs()->GetMutableDictionary(
- ExtensionDOMUI::kExtensionURLOverrides)->Set("history", list);
+ ExtensionWebUI::kExtensionURLOverrides)->Set("history", list);
ASSERT_FALSE(CheckHistoryOverridesContainsNoDupes());
diff --git a/chrome/browser/extensions/extension_popup_api.cc b/chrome/browser/extensions/extension_popup_api.cc
index 07d9ba0..1a3fe30 100644
--- a/chrome/browser/extensions/extension_popup_api.cc
+++ b/chrome/browser/extensions/extension_popup_api.cc
@@ -10,9 +10,9 @@
#include "base/string_util.h"
#include "base/stringprintf.h"
#include "base/values.h"
-#include "chrome/browser/extensions/extension_dom_ui.h"
#include "chrome/browser/extensions/extension_event_router.h"
#include "chrome/browser/extensions/extension_host.h"
+#include "chrome/browser/extensions/extension_web_ui.h"
#include "chrome/browser/profiles/profile.h"
#include "chrome/browser/renderer_host/render_view_host.h"
#include "chrome/browser/renderer_host/render_view_host_delegate.h"
diff --git a/chrome/browser/extensions/extension_service.cc b/chrome/browser/extensions/extension_service.cc
index 6cfba30..bebee43 100644
--- a/chrome/browser/extensions/extension_service.cc
+++ b/chrome/browser/extensions/extension_service.cc
@@ -33,7 +33,6 @@
#include "chrome/browser/extensions/extension_browser_event_router.h"
#include "chrome/browser/extensions/extension_cookies_api.h"
#include "chrome/browser/extensions/extension_data_deleter.h"
-#include "chrome/browser/extensions/extension_dom_ui.h"
#include "chrome/browser/extensions/extension_error_reporter.h"
#include "chrome/browser/extensions/extension_history_api.h"
#include "chrome/browser/extensions/extension_host.h"
@@ -41,6 +40,7 @@
#include "chrome/browser/extensions/extension_process_manager.h"
#include "chrome/browser/extensions/extension_processes_api.h"
#include "chrome/browser/extensions/extension_updater.h"
+#include "chrome/browser/extensions/extension_web_ui.h"
#include "chrome/browser/extensions/extension_webnavigation_api.h"
#include "chrome/browser/extensions/external_extension_provider_interface.h"
#include "chrome/browser/extensions/external_extension_provider_impl.h"
@@ -819,7 +819,7 @@ void ExtensionService::EnableExtension(const std::string& extension_id) {
// Make sure any browser action contained within it is not hidden.
extension_prefs_->SetBrowserActionVisibility(extension, true);
- ExtensionDOMUI::RegisterChromeURLOverrides(profile_,
+ ExtensionWebUI::RegisterChromeURLOverrides(profile_,
extension->GetChromeURLOverrides());
NotifyExtensionLoaded(extension);
@@ -844,7 +844,7 @@ void ExtensionService::DisableExtension(const std::string& extension_id) {
extension);
extensions_.erase(iter);
- ExtensionDOMUI::UnregisterChromeURLOverrides(profile_,
+ ExtensionWebUI::UnregisterChromeURLOverrides(profile_,
extension->GetChromeURLOverrides());
NotifyExtensionUnloaded(extension, UnloadedExtensionInfo::DISABLE);
@@ -1420,7 +1420,7 @@ void ExtensionService::UnloadExtension(
// Clean up runtime data.
extension_runtime_data_.erase(extension_id);
- ExtensionDOMUI::UnregisterChromeURLOverrides(profile_,
+ ExtensionWebUI::UnregisterChromeURLOverrides(profile_,
extension->GetChromeURLOverrides());
ExtensionList::iterator iter = std::find(disabled_extensions_.begin(),
@@ -1533,7 +1533,7 @@ void ExtensionService::OnExtensionLoaded(const Extension* extension) {
NotifyExtensionLoaded(extension);
- ExtensionDOMUI::RegisterChromeURLOverrides(
+ ExtensionWebUI::RegisterChromeURLOverrides(
profile_, extension->GetChromeURLOverrides());
break;
case Extension::DISABLED:
diff --git a/chrome/browser/extensions/extension_dom_ui.cc b/chrome/browser/extensions/extension_web_ui.cc
index 92907be..0fc87704 100644
--- a/chrome/browser/extensions/extension_dom_ui.cc
+++ b/chrome/browser/extensions/extension_web_ui.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "chrome/browser/extensions/extension_dom_ui.h"
+#include "chrome/browser/extensions/extension_web_ui.h"
#include <set>
#include <vector>
@@ -54,9 +54,9 @@ void CleanUpDuplicates(ListValue* list) {
// Helper class that is used to track the loading of the favicon of an
// extension.
-class ExtensionDOMUIImageLoadingTracker : public ImageLoadingTracker::Observer {
+class ExtensionWebUIImageLoadingTracker : public ImageLoadingTracker::Observer {
public:
- ExtensionDOMUIImageLoadingTracker(Profile* profile,
+ ExtensionWebUIImageLoadingTracker(Profile* profile,
FaviconService::GetFaviconRequest* request,
const GURL& page_url)
: ALLOW_THIS_IN_INITIALIZER_LIST(tracker_(this)),
@@ -97,7 +97,7 @@ class ExtensionDOMUIImageLoadingTracker : public ImageLoadingTracker::Observer {
}
private:
- ~ExtensionDOMUIImageLoadingTracker() {}
+ ~ExtensionWebUIImageLoadingTracker() {}
// Forwards the result on the request. If no favicon was available then
// |icon_data| may be backed by NULL. Once the result has been forwarded the
@@ -114,15 +114,15 @@ class ExtensionDOMUIImageLoadingTracker : public ImageLoadingTracker::Observer {
scoped_refptr<FaviconService::GetFaviconRequest> request_;
const Extension* extension_;
- DISALLOW_COPY_AND_ASSIGN(ExtensionDOMUIImageLoadingTracker);
+ DISALLOW_COPY_AND_ASSIGN(ExtensionWebUIImageLoadingTracker);
};
} // namespace
-const char ExtensionDOMUI::kExtensionURLOverrides[] =
+const char ExtensionWebUI::kExtensionURLOverrides[] =
"extensions.chrome_url_overrides";
-ExtensionDOMUI::ExtensionDOMUI(TabContents* tab_contents, const GURL& url)
+ExtensionWebUI::ExtensionWebUI(TabContents* tab_contents, const GURL& url)
: DOMUI(tab_contents),
url_(url) {
ExtensionService* service = tab_contents->profile()->GetExtensionService();
@@ -147,9 +147,9 @@ ExtensionDOMUI::ExtensionDOMUI(TabContents* tab_contents, const GURL& url)
}
}
-ExtensionDOMUI::~ExtensionDOMUI() {}
+ExtensionWebUI::~ExtensionWebUI() {}
-void ExtensionDOMUI::ResetExtensionFunctionDispatcher(
+void ExtensionWebUI::ResetExtensionFunctionDispatcher(
RenderViewHost* render_view_host) {
// TODO(jcivelli): http://crbug.com/60608 we should get the URL out of the
// active entry of the navigation controller.
@@ -158,7 +158,7 @@ void ExtensionDOMUI::ResetExtensionFunctionDispatcher(
DCHECK(extension_function_dispatcher_.get());
}
-void ExtensionDOMUI::ResetExtensionBookmarkManagerEventRouter() {
+void ExtensionWebUI::ResetExtensionBookmarkManagerEventRouter() {
// Hack: A few things we specialize just for the bookmark manager.
if (extension_function_dispatcher_->extension_id() ==
extension_misc::kBookmarkManagerId) {
@@ -169,22 +169,22 @@ void ExtensionDOMUI::ResetExtensionBookmarkManagerEventRouter() {
}
}
-void ExtensionDOMUI::RenderViewCreated(RenderViewHost* render_view_host) {
+void ExtensionWebUI::RenderViewCreated(RenderViewHost* render_view_host) {
ResetExtensionFunctionDispatcher(render_view_host);
ResetExtensionBookmarkManagerEventRouter();
}
-void ExtensionDOMUI::RenderViewReused(RenderViewHost* render_view_host) {
+void ExtensionWebUI::RenderViewReused(RenderViewHost* render_view_host) {
ResetExtensionFunctionDispatcher(render_view_host);
ResetExtensionBookmarkManagerEventRouter();
}
-void ExtensionDOMUI::ProcessDOMUIMessage(
+void ExtensionWebUI::ProcessDOMUIMessage(
const ViewHostMsg_DomMessage_Params& params) {
extension_function_dispatcher_->HandleRequest(params);
}
-Browser* ExtensionDOMUI::GetBrowser() {
+Browser* ExtensionWebUI::GetBrowser() {
TabContents* contents = tab_contents();
TabContentsIterator tab_iterator;
for (; !tab_iterator.done(); ++tab_iterator) {
@@ -195,16 +195,16 @@ Browser* ExtensionDOMUI::GetBrowser() {
return NULL;
}
-TabContents* ExtensionDOMUI::associated_tab_contents() const {
+TabContents* ExtensionWebUI::associated_tab_contents() const {
return tab_contents();
}
ExtensionBookmarkManagerEventRouter*
-ExtensionDOMUI::extension_bookmark_manager_event_router() {
+ExtensionWebUI::extension_bookmark_manager_event_router() {
return extension_bookmark_manager_event_router_.get();
}
-gfx::NativeWindow ExtensionDOMUI::GetCustomFrameNativeWindow() {
+gfx::NativeWindow ExtensionWebUI::GetCustomFrameNativeWindow() {
if (GetBrowser())
return NULL;
@@ -218,7 +218,7 @@ gfx::NativeWindow ExtensionDOMUI::GetCustomFrameNativeWindow() {
return NULL;
}
-gfx::NativeView ExtensionDOMUI::GetNativeViewOfHost() {
+gfx::NativeView ExtensionWebUI::GetNativeViewOfHost() {
return tab_contents()->GetRenderWidgetHostView()->GetNativeView();
}
@@ -226,12 +226,12 @@ gfx::NativeView ExtensionDOMUI::GetNativeViewOfHost() {
// chrome:// URL overrides
// static
-void ExtensionDOMUI::RegisterUserPrefs(PrefService* prefs) {
+void ExtensionWebUI::RegisterUserPrefs(PrefService* prefs) {
prefs->RegisterDictionaryPref(kExtensionURLOverrides);
}
// static
-bool ExtensionDOMUI::HandleChromeURLOverride(GURL* url, Profile* profile) {
+bool ExtensionWebUI::HandleChromeURLOverride(GURL* url, Profile* profile) {
if (!url->SchemeIs(chrome::kChromeUIScheme))
return false;
@@ -292,7 +292,7 @@ bool ExtensionDOMUI::HandleChromeURLOverride(GURL* url, Profile* profile) {
}
// static
-void ExtensionDOMUI::RegisterChromeURLOverrides(
+void ExtensionWebUI::RegisterChromeURLOverrides(
Profile* profile, const Extension::URLOverrideMap& overrides) {
if (overrides.empty())
return;
@@ -335,7 +335,7 @@ void ExtensionDOMUI::RegisterChromeURLOverrides(
}
// static
-void ExtensionDOMUI::UnregisterAndReplaceOverride(const std::string& page,
+void ExtensionWebUI::UnregisterAndReplaceOverride(const std::string& page,
Profile* profile, ListValue* list, Value* override) {
int index = list->Remove(*override);
if (index == 0) {
@@ -358,7 +358,7 @@ void ExtensionDOMUI::UnregisterAndReplaceOverride(const std::string& page,
}
// static
-void ExtensionDOMUI::UnregisterChromeURLOverride(const std::string& page,
+void ExtensionWebUI::UnregisterChromeURLOverride(const std::string& page,
Profile* profile, Value* override) {
if (!override)
return;
@@ -376,7 +376,7 @@ void ExtensionDOMUI::UnregisterChromeURLOverride(const std::string& page,
}
// static
-void ExtensionDOMUI::UnregisterChromeURLOverrides(
+void ExtensionWebUI::UnregisterChromeURLOverrides(
Profile* profile, const Extension::URLOverrideMap& overrides) {
if (overrides.empty())
return;
@@ -400,10 +400,10 @@ void ExtensionDOMUI::UnregisterChromeURLOverrides(
}
// static
-void ExtensionDOMUI::GetFaviconForURL(Profile* profile,
+void ExtensionWebUI::GetFaviconForURL(Profile* profile,
FaviconService::GetFaviconRequest* request, const GURL& page_url) {
// tracker deletes itself when done.
- ExtensionDOMUIImageLoadingTracker* tracker =
- new ExtensionDOMUIImageLoadingTracker(profile, request, page_url);
+ ExtensionWebUIImageLoadingTracker* tracker =
+ new ExtensionWebUIImageLoadingTracker(profile, request, page_url);
tracker->Init();
}
diff --git a/chrome/browser/extensions/extension_dom_ui.h b/chrome/browser/extensions/extension_web_ui.h
index c0f8cf6..5ae1233 100644
--- a/chrome/browser/extensions/extension_dom_ui.h
+++ b/chrome/browser/extensions/extension_web_ui.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_EXTENSIONS_EXTENSION_DOM_UI_H_
-#define CHROME_BROWSER_EXTENSIONS_EXTENSION_DOM_UI_H_
+#ifndef CHROME_BROWSER_EXTENSIONS_EXTENSION_WEB_UI_H_
+#define CHROME_BROWSER_EXTENSIONS_EXTENSION_WEB_UI_H_
#pragma once
#include <string>
@@ -27,15 +27,15 @@ struct ViewHostMsg_DomMessage_Params;
// the main tab contents area. For example, each extension can specify an
// "options_page", and that page is displayed in the tab contents area and is
// hosted by this class.
-class ExtensionDOMUI
+class ExtensionWebUI
: public DOMUI,
public ExtensionFunctionDispatcher::Delegate {
public:
static const char kExtensionURLOverrides[];
- explicit ExtensionDOMUI(TabContents* tab_contents, const GURL& url);
+ explicit ExtensionWebUI(TabContents* tab_contents, const GURL& url);
- virtual ~ExtensionDOMUI();
+ virtual ~ExtensionWebUI();
ExtensionFunctionDispatcher* extension_function_dispatcher() const {
return extension_function_dispatcher_.get();
@@ -103,4 +103,4 @@ class ExtensionDOMUI
GURL url_;
};
-#endif // CHROME_BROWSER_EXTENSIONS_EXTENSION_DOM_UI_H_
+#endif // CHROME_BROWSER_EXTENSIONS_EXTENSION_WEB_UI_H_
diff --git a/chrome/browser/prefs/browser_prefs.cc b/chrome/browser/prefs/browser_prefs.cc
index 80d6477..a3a498f 100644
--- a/chrome/browser/prefs/browser_prefs.cc
+++ b/chrome/browser/prefs/browser_prefs.cc
@@ -17,8 +17,8 @@
#include "chrome/browser/dom_ui/new_tab_ui.h"
#include "chrome/browser/dom_ui/plugins_ui.h"
#include "chrome/browser/download/download_prefs.h"
-#include "chrome/browser/extensions/extension_dom_ui.h"
#include "chrome/browser/extensions/extension_prefs.h"
+#include "chrome/browser/extensions/extension_web_ui.h"
#include "chrome/browser/extensions/extensions_ui.h"
#include "chrome/browser/external_protocol_handler.h"
#include "chrome/browser/geolocation/geolocation_content_settings_map.h"
@@ -126,7 +126,7 @@ void RegisterUserPrefs(PrefService* user_prefs) {
bookmark_utils::RegisterUserPrefs(user_prefs);
TabContents::RegisterUserPrefs(user_prefs);
TemplateURLPrepopulateData::RegisterUserPrefs(user_prefs);
- ExtensionDOMUI::RegisterUserPrefs(user_prefs);
+ ExtensionWebUI::RegisterUserPrefs(user_prefs);
ExtensionsUI::RegisterUserPrefs(user_prefs);
NewTabUI::RegisterUserPrefs(user_prefs);
PluginsUI::RegisterUserPrefs(user_prefs);
diff --git a/chrome/browser/tab_contents/web_drag_dest_gtk.cc b/chrome/browser/tab_contents/web_drag_dest_gtk.cc
index 8d2da35..2a80e7b 100644
--- a/chrome/browser/tab_contents/web_drag_dest_gtk.cc
+++ b/chrome/browser/tab_contents/web_drag_dest_gtk.cc
@@ -232,7 +232,7 @@ void WebDragDestGtk::OnDragDataReceived(
gtk_util::ScreenPoint(widget_),
gtk_util::GdkDragActionToWebDragOp(context->actions));
- // This is non-null if tab_contents_ is showing an ExtensionDOMUI with
+ // This is non-null if tab_contents_ is showing an ExtensionWebUI with
// support for (at the moment experimental) drag and drop extensions.
if (tab_contents_->GetBookmarkDragDelegate()) {
tab_contents_->GetBookmarkDragDelegate()->OnDragEnter(
@@ -268,7 +268,7 @@ gboolean WebDragDestGtk::OnDragDrop(GtkWidget* sender, GdkDragContext* context,
DragTargetDrop(gtk_util::ClientPoint(widget_),
gtk_util::ScreenPoint(widget_));
- // This is non-null if tab_contents_ is showing an ExtensionDOMUI with
+ // This is non-null if tab_contents_ is showing an ExtensionWebUI with
// support for (at the moment experimental) drag and drop extensions.
if (tab_contents_->GetBookmarkDragDelegate())
tab_contents_->GetBookmarkDragDelegate()->OnDrop(bookmark_drag_data_);
diff --git a/chrome/browser/tab_contents/web_drop_target_win.cc b/chrome/browser/tab_contents/web_drop_target_win.cc
index d7ccf9b..1c27d8b 100644
--- a/chrome/browser/tab_contents/web_drop_target_win.cc
+++ b/chrome/browser/tab_contents/web_drop_target_win.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -121,7 +121,7 @@ DWORD WebDropTarget::OnDragEnter(IDataObject* data_object,
gfx::Point(cursor_position.x, cursor_position.y),
web_drag_utils_win::WinDragOpMaskToWebDragOpMask(effects));
- // This is non-null if tab_contents_ is showing an ExtensionDOMUI with
+ // This is non-null if tab_contents_ is showing an ExtensionWebUI with
// support for (at the moment experimental) drag and drop extensions.
if (tab_contents_->GetBookmarkDragDelegate()) {
ui::OSExchangeData os_exchange_data(
diff --git a/chrome/chrome_browser.gypi b/chrome/chrome_browser.gypi
index 34daa6a..0105839 100644
--- a/chrome/chrome_browser.gypi
+++ b/chrome/chrome_browser.gypi
@@ -1089,8 +1089,6 @@
'browser/extensions/extension_devtools_manager.h',
'browser/extensions/extension_disabled_infobar_delegate.cc',
'browser/extensions/extension_disabled_infobar_delegate.h',
- 'browser/extensions/extension_dom_ui.cc',
- 'browser/extensions/extension_dom_ui.h',
'browser/extensions/extension_error_reporter.cc',
'browser/extensions/extension_error_reporter.h',
'browser/extensions/extension_event_names.cc',
@@ -1189,6 +1187,8 @@
'browser/extensions/extension_tts_api_win.cc',
'browser/extensions/extension_updater.cc',
'browser/extensions/extension_updater.h',
+ 'browser/extensions/extension_web_ui.cc',
+ 'browser/extensions/extension_web_ui.h',
'browser/extensions/extension_webrequest_api.cc',
'browser/extensions/extension_webrequest_api.h',
'browser/extensions/extension_webnavigation_api.cc',
diff --git a/chrome/browser/dom_ui/web_ui_factory.cc b/chrome/browser/dom_ui/web_ui_factory.cc
index d6a6d86..c392dc9 100644
--- a/chrome/browser/dom_ui/web_ui_factory.cc
+++ b/chrome/browser/dom_ui/web_ui_factory.cc
@@ -25,8 +25,8 @@
#include "chrome/browser/dom_ui/slideshow_ui.h"
#include "chrome/browser/dom_ui/sync_internals_ui.h"
#include "chrome/browser/dom_ui/textfields_ui.h"
-#include "chrome/browser/extensions/extension_dom_ui.h"
#include "chrome/browser/extensions/extension_service.h"
+#include "chrome/browser/extensions/extension_web_ui.h"
#include "chrome/browser/extensions/extensions_ui.h"
#include "chrome/browser/printing/print_dialog_cloud.h"
#include "chrome/browser/profiles/profile.h"
@@ -73,13 +73,13 @@ DOMUI* NewDOMUI(TabContents* contents, const GURL& url) {
// Special case for extensions.
template<>
-DOMUI* NewDOMUI<ExtensionDOMUI>(TabContents* contents, const GURL& url) {
+DOMUI* NewDOMUI<ExtensionWebUI>(TabContents* contents, const GURL& url) {
// Don't use a DOMUI for incognito tabs because we require extensions to run
// within a single process.
ExtensionService* service = contents->profile()->GetExtensionService();
if (service &&
service->ExtensionBindingsAllowed(url)) {
- return new ExtensionDOMUI(contents, url);
+ return new ExtensionWebUI(contents, url);
}
return NULL;
}
@@ -87,7 +87,7 @@ DOMUI* NewDOMUI<ExtensionDOMUI>(TabContents* contents, const GURL& url) {
// Returns a function that can be used to create the right type of DOMUI for a
// tab, based on its URL. Returns NULL if the URL doesn't have DOMUI associated
// with it. Even if the factory function is valid, it may yield a NULL DOMUI
// when invoked for a particular tab - see NewDOMUI<ExtensionDOMUI>.
static WebUIFactoryFunction GetWebUIFactoryFunction(Profile* profile,
const GURL& url) {
// Currently, any gears: URL means an HTML dialog.
@@ -99,7 +99,7 @@ static WebUIFactoryFunction GetWebUIFactoryFunction(Profile* profile,
ExtensionService* service = profile ? profile->GetExtensionService() : NULL;
if (service && service->ExtensionBindingsAllowed(url))
- return &NewDOMUI<ExtensionDOMUI>;
+ return &NewDOMUI<ExtensionWebUI>;
// All platform builds of Chrome will need to have a cloud printing
// dialog as backup. It's just that on Chrome OS, it's the only
@@ -276,7 +276,7 @@ void WebUIFactory::GetFaviconForURL(Profile* profile,
// part of the manifest.
if (page_url.SchemeIs(chrome::kExtensionScheme) &&
page_url.host() != extension_misc::kBookmarkManagerId) {
- ExtensionDOMUI::GetFaviconForURL(profile, request, page_url);
+ ExtensionWebUI::GetFaviconForURL(profile, request, page_url);
} else {
scoped_refptr<RefCountedMemory> icon_data(
WebUIFactory::GetFaviconResourceBytes(profile, page_url));
@@ -87,7 +87,7 @@ DOMUI* NewDOMUI<ExtensionDOMUI>(TabContents* contents, const GURL& url) {
// tab, based on its URL. Returns NULL if the URL doesn't have DOMUI associated
// with it. Even if the factory function is valid, it may yield a NULL DOMUI
-// when invoked for a particular tab - see NewDOMUI<ExtensionDOMUI>.
+// when invoked for a particular tab - see NewDOMUI<ExtensionWebUI>.
static WebUIFactoryFunction GetWebUIFactoryFunction(Profile* profile,
const GURL& url) {